@@ -29,7 +29,7 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.TimeZone;
 
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -40,7 +40,6 @@ import org.apache.catalina.Wrapper;
 import org.apache.catalina.startup.SimpleHttpClient;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
-import org.apache.coyote.http11.AbstractHttp11Protocol;
 import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.descriptor.web.ErrorPage;
 import org.apache.tomcat.websocket.server.WsContextListener;
@@ -87,43 +86,6 @@ public class TestDefaultServlet extends TomcatBaseTest {
 
     }
 
-    @Test
-    public void testDefaultCompression() throws Exception {
-
-        Tomcat tomcat = getTomcatInstance();
-        ((AbstractHttp11Protocol<?>) tomcat.getConnector().getProtocolHandler()).setCompression("force");
-
-        File appDir = new File("test/webapp");
-
-        // app dir is relative to server home
-        Context ctxt = tomcat.addContext("", appDir.getAbsolutePath());
-        Wrapper defaultServlet = Tomcat.addServlet(ctxt, "default",
-                "org.apache.catalina.servlets.DefaultServlet");
-        defaultServlet.addInitParameter("fileEncoding", "ISO-8859-1");
-        ctxt.addServletMappingDecoded("/", "default");
-
-        ctxt.addMimeMapping("html", "text/html");
-
-        tomcat.start();
-
-        TestCompressedClient gzipClient = new TestCompressedClient(getPort());
-
-        gzipClient.reset();
-        gzipClient.setRequest(new String[] {
-                "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: gzip" + CRLF + CRLF });
-        gzipClient.connect();
-        gzipClient.processRequest();
-        Assert.assertTrue(gzipClient.isResponse200());
-        List<String> responseHeaders = gzipClient.getResponseHeaders();
-        Assert.assertTrue(responseHeaders.contains("Content-Encoding: gzip"));
-        for (String header : responseHeaders) {
-            Assert.assertFalse(header.startsWith("Content-Length: "));
-        }
-    }
-
     /*
      * Verify serving of gzipped resources from context root.
      */
@@ -211,15 +173,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         TestCompressedClient client = new TestCompressedClient(getPort());
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: br, gzip" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: br, gzip" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -229,14 +187,10 @@ public class TestDefaultServlet extends TomcatBaseTest {
         Assert.assertTrue(responseHeaders.contains("vary: accept-encoding"));
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF+ CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -274,15 +228,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         TestCompressedClient client = new TestCompressedClient(getPort());
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: br, gzip ; q = 0.5 , custom" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: br, gzip ; q = 0.5 , custom" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -292,14 +242,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         Assert.assertTrue(responseHeaders.contains("vary: accept-encoding"));
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: br;q=1,gzip,custom" + CRLF +
-                CRLF });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: br;q=1,gzip,custom" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -337,15 +284,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         TestCompressedClient client = new TestCompressedClient(getPort());
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: gzip;q=0.9,*" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: gzip;q=0.9,*" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -355,15 +298,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         Assert.assertTrue(responseHeaders.contains("vary: accept-encoding"));
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: gzip;q=0.9,br;q=0,identity," + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: gzip;q=0.9,br;q=0,identity," + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -400,15 +339,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
 
         // Firefox 45 Accept-Encoding
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: gzip, deflate, br" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: gzip, deflate, br" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -419,15 +354,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
 
         // Chrome 50 Accept-Encoding
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /index.html HTTP/1.1" + CRLF +
-                "Host: localhost" + CRLF +
-                "Connection: Close" + CRLF +
-                "Accept-Encoding: gzip, deflate, sdch, br" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                        "Host: localhost" + CRLF +
+                        "Connection: Close" + CRLF +
+                        "Accept-Encoding: gzip, deflate, sdch, br" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse200());
@@ -449,7 +380,8 @@ public class TestDefaultServlet extends TomcatBaseTest {
 
         File appDir = new File(getBuildDirectory(), "webapps" + contextPath);
         // app dir is relative to server home
-        Context ctx = tomcat.addWebapp(null, "/examples", appDir.getAbsolutePath());
+        org.apache.catalina.Context ctx =
+            tomcat.addWebapp(null, "/examples", appDir.getAbsolutePath());
         ctx.addApplicationListener(WsContextListener.class.getName());
 
         // Override the default servlet with our own mappings
@@ -537,12 +469,8 @@ public class TestDefaultServlet extends TomcatBaseTest {
                 new TestCustomErrorClient(tomcat.getConnector().getLocalPort());
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
-                "GET /MyApp/missing HTTP/1.0" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                "GET /MyApp/missing HTTP/1.0" +CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse404());
@@ -557,15 +485,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         // https://bz.apache.org/bugzilla/show_bug.cgi?id=50413
         //
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /MyApp/missing HTTP/1.1" + CRLF +
                 "Host: localhost" + CRLF +
                 "Connection: close" + CRLF +
-                "If-Modified-Since: " + tomorrow + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                "If-Modified-Since: " + tomorrow + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse404());
@@ -574,15 +498,11 @@ public class TestDefaultServlet extends TomcatBaseTest {
         // https://bz.apache.org/bugzilla/show_bug.cgi?id=50413#c6
         //
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
                 "GET /MyApp/missing HTTP/1.1" + CRLF +
                 "Host: localhost" + CRLF +
                 "Connection: close" + CRLF +
-                "Range: bytes=0-100" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                "Range: bytes=0-100" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse404());
@@ -605,17 +525,15 @@ public class TestDefaultServlet extends TomcatBaseTest {
         File webxml = new File(appDir, "WEB-INF/web.xml");
         try (FileOutputStream fos = new FileOutputStream(webxml);
                 Writer w = new OutputStreamWriter(fos, "UTF-8")) {
-            // @formatter:off
-            w.write("<?xml version='1.0' encoding='UTF-8'?>\n" +
-                    "<web-app xmlns='http://java.sun.com/xml/ns/j2ee' " +
-                    " xmlns:xsi='http://www.w3.org/2001/XMLSchema-instance'" +
-                    " xsi:schemaLocation='http://java.sun.com/xml/ns/j2ee " +
-                    " http://java.sun.com/xml/ns/j2ee/web-app_2_4.xsd'" +
-                    " version='2.4'>\n" +
-                    "<error-page>\n<error-code>404</error-code>\n" +
-                    "<location>/404-absent.html</location>\n</error-page>\n" +
-                    "</web-app>\n");
-            // @formatter:on
+            w.write("<?xml version='1.0' encoding='UTF-8'?>\n"
+                    + "<web-app xmlns='http://java.sun.com/xml/ns/j2ee' "
+                    + " xmlns:xsi='http://www.w3.org/2001/XMLSchema-instance'"
+                    + " xsi:schemaLocation='http://java.sun.com/xml/ns/j2ee "
+                    + " http://java.sun.com/xml/ns/j2ee/web-app_2_4.xsd'"
+                    + " version='2.4'>\n"
+                    + "<error-page>\n<error-code>404</error-code>\n"
+                    + "<location>/404-absent.html</location>\n</error-page>\n"
+                    + "</web-app>\n");
         }
 
         Tomcat tomcat = getTomcatInstance();
@@ -627,12 +545,8 @@ public class TestDefaultServlet extends TomcatBaseTest {
                 new TestCustomErrorClient(tomcat.getConnector().getLocalPort());
 
         client.reset();
-        // @formatter:off
         client.setRequest(new String[] {
-                "GET /MyApp/missing HTTP/1.0" + CRLF +
-                CRLF
-                });
-        // @formatter:on
+                "GET /MyApp/missing HTTP/1.0" + CRLF + CRLF });
         client.connect();
         client.processRequest();
         Assert.assertTrue(client.isResponse404());
@@ -673,7 +587,7 @@ public class TestDefaultServlet extends TomcatBaseTest {
 
     private static class TestCustomErrorClient extends SimpleHttpClient {
 
-        TestCustomErrorClient(int port) {
+        public TestCustomErrorClient(int port) {
             setPort(port);
         }
 
@@ -685,7 +599,7 @@ public class TestDefaultServlet extends TomcatBaseTest {
 
     private static class TestCompressedClient extends SimpleHttpClient {
 
-        TestCompressedClient(int port) {
+        public TestCompressedClient(int port) {
             setPort(port);
         }
 
@@ -694,85 +608,4 @@ public class TestDefaultServlet extends TomcatBaseTest {
             return true;
         }
     }
-
-    /*
-     * Bug 66609
-     */
-    @Test
-    public void testXmlDirectoryListing() throws Exception {
-        Tomcat tomcat = getTomcatInstance();
-
-        File appDir = new File("test/webapp");
-        Context ctxt = tomcat.addContext("", appDir.getAbsolutePath());
-
-        Wrapper defaultServlet = Tomcat.addServlet(ctxt, "default", new DefaultServlet());
-        defaultServlet.addInitParameter("listings", "true");
-        defaultServlet.addInitParameter("localXsltFile", "_listing.xslt");
-
-        ctxt.addServletMappingDecoded("/", "default");
-
-        tomcat.start();
-
-        Map<String,List<String>> resHeaders= new HashMap<>();
-        String path = "http://localhost:" + getPort() + "/bug66609/";
-        ByteChunk out = new ByteChunk();
-
-        int rc = getUrl(path, out, resHeaders);
-        Assert.assertEquals(HttpServletResponse.SC_OK, rc);
-        String length = resHeaders.get("Content-Length").get(0);
-        Assert.assertEquals(Long.parseLong(length), out.getLength());
-        out.recycle();
-
-        rc = headUrl(path, out, resHeaders);
-        Assert.assertEquals(HttpServletResponse.SC_OK, rc);
-        Assert.assertEquals(0, out.getLength());
-        Assert.assertEquals(length, resHeaders.get("Content-Length").get(0));
-    }
-
-    @Test
-    public void testDirectoryListing() throws Exception {
-        Tomcat tomcat = getTomcatInstance();
-
-        File appDir = new File("test/webapp");
-        Context ctxt = tomcat.addContext("", appDir.getAbsolutePath());
-
-        Wrapper defaultServlet = Tomcat.addServlet(ctxt, "default", new DefaultServlet());
-        defaultServlet.addInitParameter("listings", "true");
-        defaultServlet.addInitParameter("sortListings", "true");
-        defaultServlet.addInitParameter("sortDirectoriesFirst", "true");
-
-        ctxt.addServletMappingDecoded("/", "default");
-
-        tomcat.start();
-
-        TestCompressedClient client = new TestCompressedClient(getPort());
-
-        // @formatter:off
-        client.setRequest(new String[] {
-                "GET / HTTP/1.1" + CRLF +
-                "Host: localhost:" + getPort() + CRLF +
-                "Accept-Language: fr-FR, fr, en" + CRLF +
-                "Connection: Close" + CRLF +
-                CRLF
-                });
-        // @formatter:on
-        client.connect();
-        client.processRequest(true);
-        Assert.assertEquals(HttpServletResponse.SC_OK, client.getStatusCode());
-        Assert.assertTrue(client.getResponseBody().contains("Taille"));
-        Assert.assertTrue(client.getResponseBody().contains("<tt>bug43nnn/"));
-
-        // @formatter:off
-        client.setRequest(new String[] {
-                "GET /bug43nnn/ HTTP/1.1" + CRLF +
-                "Host: localhost:" + getPort() + CRLF +
-                "Accept-Language: fr-FR, fr, en" + CRLF +
-                "Connection: Close" + CRLF +
-                CRLF
-                });
-        // @formatter:on
-        client.connect();
-        client.processRequest(true);
-        Assert.assertEquals(HttpServletResponse.SC_OK, client.getStatusCode());
-    }
 }
