@@ -37,15 +37,15 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.CountDownLatch;
 
-import javax.servlet.AsyncContext;
-import javax.servlet.DispatcherType;
-import javax.servlet.ReadListener;
-import javax.servlet.ServletException;
-import javax.servlet.ServletInputStream;
-import javax.servlet.http.Cookie;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.AsyncContext;
+import jakarta.servlet.DispatcherType;
+import jakarta.servlet.ReadListener;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletInputStream;
+import jakarta.servlet.http.Cookie;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -117,7 +117,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
 
         private final boolean useChunks;
 
-        ResponseWithErrorServlet(boolean useChunks) {
+        public ResponseWithErrorServlet(boolean useChunks) {
             this.useChunks = useChunks;
         }
 
@@ -531,7 +531,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
                 "Accept-Language: en-US,en;q=0.8,fr;q=0.6,es;q=0.4\r\n" +
                 "\r\n";
 
-        try (Socket connection = new Socket("localhost", getPort())) {
+        try (final Socket connection = new Socket("localhost", getPort())) {
             connection.setSoLinger(true, 0);
             Writer writer = new OutputStreamWriter(connection.getOutputStream(),
                     StandardCharsets.US_ASCII);
@@ -545,7 +545,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
         bug55772Latch2.await();
         bug55772IsSecondRequest = true;
 
-        try (Socket connection = new Socket("localhost", getPort())) {
+        try (final Socket connection = new Socket("localhost", getPort())) {
             connection.setSoLinger(true, 0);
             Writer writer = new OutputStreamWriter(connection.getOutputStream(),
                     B2CConverter.getCharset("US-ASCII"));
@@ -669,7 +669,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
 
         boolean flush = false;
 
-        LargeHeaderServlet(boolean flush) {
+        public LargeHeaderServlet(boolean flush) {
             this.flush = flush;
         }
 
@@ -726,7 +726,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
 
     private static final class Client extends SimpleHttpClient {
 
-        Client(int port) {
+        public Client(int port) {
             setPort(port);
         }
 
@@ -790,7 +790,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
         private final boolean delayAsyncThread;
 
 
-        Bug57621Servlet(boolean delayAsyncThread) {
+        public Bug57621Servlet(boolean delayAsyncThread) {
             this.delayAsyncThread = delayAsyncThread;
         }
 
@@ -1772,7 +1772,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
 
         private static final long serialVersionUID = 1L;
 
-        SwallowBodyTesterServlet() {
+        public SwallowBodyTesterServlet() {
             super(true);
         }
 
@@ -1805,7 +1805,7 @@ public class TestHttp11Processor extends TomcatBaseTest {
             // Needs to be async to trigger the problematic code path
             AsyncContext ac = req.startAsync();
             ServletInputStream sis = req.getInputStream();
-            // This triggers a call to Http11InputBuffer.available(true) which
+            // This triggers a call to Http11InputBuffer.avalable(true) which
             // did not handle the pipelining case.
             sis.setReadListener(new Bug64974ReadListener());
             ac.complete();
@@ -1942,58 +1942,4 @@ public class TestHttp11Processor extends TomcatBaseTest {
         Assert.assertTrue(client.isResponse200());
         Assert.assertTrue(client.getResponseBody().contains("test - data"));
     }
-
-
-    @Test
-    public void test100ContinueWithNoAck() throws Exception {
-        Tomcat tomcat = getTomcatInstance();
-
-        final Connector connector = tomcat.getConnector();
-        connector.setProperty("continueResponseTiming", "onRead");
-
-        // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
-
-        // Add servlet
-        Tomcat.addServlet(ctx, "TestPostNoReadServlet", new TestPostNoReadServlet());
-        ctx.addServletMappingDecoded("/foo", "TestPostNoReadServlet");
-
-        tomcat.start();
-
-        String request =
-            "POST /foo HTTP/1.1" + SimpleHttpClient.CRLF +
-                "Host: localhost:" + getPort() + SimpleHttpClient.CRLF +
-                "Expect: 100-continue"  + SimpleHttpClient.CRLF +
-                "Content-Length: 10"  + SimpleHttpClient.CRLF +
-                SimpleHttpClient.CRLF +
-                "0123456789";
-
-        Client client = new Client(tomcat.getConnector().getLocalPort());
-        client.setRequest(new String[] {request});
-
-        client.connect();
-        client.processRequest(false);
-
-        Assert.assertTrue(client.isResponse200());
-
-        if (client.getResponseHeaders().contains("Connection: close")) {
-            client.connect();
-        }
-
-        client.processRequest(false);
-
-        Assert.assertTrue(client.isResponse200());
-
-    }
-
-
-    private static class TestPostNoReadServlet extends HttpServlet {
-
-        private static final long serialVersionUID = 1L;
-
-        @Override
-        protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
-
-        }
-    }
 }
